[Libguestfs] [p2v PATCH] Ignore 'rhv-upload' driver (RHBZ#1590220)

Pino Toscano ptoscano at redhat.com
Wed Sep 18 14:25:58 UTC 2019


The 'rhv-upload' output mode requires few options, and virt-p2v does not
have the GUI bits for specifying them.
---
 ssh.c | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/ssh.c b/ssh.c
index 7d85b40..99eefbd 100644
--- a/ssh.c
+++ b/ssh.c
@@ -1022,8 +1022,12 @@ add_input_driver (const char *name, size_t len)
 static void
 add_output_driver (const char *name, size_t len)
 {
-  /* Ignore the 'vdsm' driver, since that should only be used by VDSM. */
-  if (len != 4 || memcmp (name, "vdsm", 4) != 0)
+  /* Ignore the 'vdsm' driver, since that should only be used by VDSM.
+   * Ignore the 'rhv-upload' driver, since we do not support passing all the
+   * options for it.
+   */
+  if ((len != 4 || memcmp (name, "vdsm", 4) != 0) &&
+      (len != 10 || memcmp (name, "rhv-upload", 10) != 0))
     add_option ("output", &output_drivers, name, len);
 }
 
-- 
2.21.0




More information about the Libguestfs mailing list